//---------------------------------------------------------
// Copyright 2015 Ontario Institute for Cancer Research
// Written by Jared Simpson (jared.simpson@oicr.on.ca)
//---------------------------------------------------------
//
// nanopolish_getmodel.h - write the pore model for a read
// to stdout
//
#ifndef NANOPOLISH_GETMODEL_H
#define NANOPOLISH_GETMODEL_H

int getmodel_main(int argc, char** argv);

#endif
